# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2017-04-17 18:37
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('visaweb', '0003_auto_20170417_1832'),
    ]

    operations = [
        migrations.AddField(
            model_name='command',
            name='name',
            field=models.CharField(default='trace', max_length=200),
            preserve_default=False,
        ),
    ]
