/*
 * PolymerThemes v1.0.3
 * Homepage: https://polymerthemes.com
 * Copyright 2015 Polymer Themes
 * Licensed under BSD
 * Based on Polymer: http://www.polymer-project.org/
 * Compatible with Polymer 1.0
 */

@import url("https://fonts.googleapis.com/css?family=Oxygen:700|Source+Sans+Pro");
html { -ms-text-size-adjust: 100%; -webkit-text-size-adjust: 100%; font-size: 16px; }

html, body { margin: 0px; padding: 0px; min-height: 100%; color: #444444; background-color: #ffffff; font-family: 'Source Sans Pro', sans-serif; font-weight: 400; }

section { padding: 40px 0px; }
section[hero] { background-color: #f2f7fa; }

h1, h2, h3, h4, h5, h6 { font-weight: 400; margin: 0px; padding: 0px; line-height: 1em; }

h1, h3, h5 { font-family: 'Oxygen', sans-serif; }

h1 { font-size: 50px; margin: 30px 0px; }

h2 { color: #444444; font-size: 35px; margin: 20px 0px; }

h3 { font-size: 25px; margin: 15px 0px; }

h4 { font-size: 20px; }

a, a:active, a:visited, a:focus { color: #444444; text-decoration: none; }

a:hover { color: #444444; text-decoration: underline; }

:root { --default-primary-color: #373b50; --dark-primary-color: #373b50; --light-primary-color: #c5cae9; --text-primary-color: #ffffff; --accent-color: #ff4081; --primary-background-color: #ffffff; --primary-text-color: #444444; --secondary-text-color: #444444; --disabled-text-color: #313238; --divider-color: #e0e0e0; --paper-checkbox-checked-color: #373b50; --paper-checkbox-checked-ink-color: #373b50; --paper-checkbox-unchecked-color: #444444; --paper-checkbox-unchecked-ink-color: #444444; --paper-checkbox-label-color: #444444; --paper-fab-background: #373b50; --paper-fab-disabled-background: #afb1b9; --paper-fab-disabled-text: #313238; --paper-icon-button-disabled-text: #afb1b9; --paper-input-container-color: #919191; --paper-input-container-focus-color: #373b50; --paper-input-container-invalid-color: #ff6e40; --paper-input-container-input-color: #919191; --paper-menu-background-color: #f2f7fa; --paper-menu-color: #444444; --paper-menu-disabled-color: #afb1b9; --paper-progress-active-color: #373b50; --paper-progress-secondary-color: #90a4ae; --paper-radio-button-checked-color: #373b50; --paper-radio-button-checked-ink-color: #d6d8e3; --paper-radio-button-unchecked-color: #444444; --paper-radio-button-unchecked-ink-color: #444444; --paper-radio-button-label-color: #444444; --paper-slider-knob-color: #373b50; --paper-slider-active-color: #373b50; --paper-slider-pin-color: #373b50; --paper-spinner-layer-1-color: #373b50; --paper-spinner-layer-2-color: #373b50; --paper-spinner-layer-3-color: #373b50; --paper-spinner-layer-4-color: #373b50; --paper-tabs-selection-bar-color: #90a4ae; --paper-tab-ink: #90a4ae; --paper-toggle-button-checked-bar-color: #373b50; --paper-toggle-button-checked-button-color: #373b50; --paper-toggle-button-checked-ink-color: #373b50; --paper-toggle-button-unchecked-bar-color: #444444; --paper-toggle-button-unchecked-button-color: white; --paper-toggle-button-unchecked-ink-color: white; --paper-toolbar-background: #373b50; --paper-toolbar-color: #ffffff; }

paper-toolbar a, paper-toolbar a:hover, paper-toolbar a:active, paper-toolbar a:visited, paper-toolbar a:focus { color: #ffffff; }

paper-button.primary, paper-button.btn-primary, paper-button[primary] { color: #373b50; }
paper-button.primary[raised], paper-button.btn-primary[raised], paper-button[primary][raised] { background-color: #373b50; color: #fff; }
paper-button.secondary, paper-button.btn-secondary, paper-button[secondary] { color: #90a4ae; }
paper-button.secondary[raised], paper-button.btn-secondary[raised], paper-button[secondary][raised] { background-color: #90a4ae; color: #2b3134; }
paper-button.success, paper-button.btn-success, paper-button[success] { color: #9dc56e; }
paper-button.success[raised], paper-button.btn-success[raised], paper-button[success][raised] { background-color: #9dc56e; color: #2f3b21; }
paper-button.info, paper-button.btn-info, paper-button[info] { color: #ffb74d; }
paper-button.info[raised], paper-button.btn-info[raised], paper-button[info][raised] { background-color: #ffb74d; color: #4d3717; }
paper-button.warning, paper-button.btn-warning, paper-button[warning] { color: #fadd60; }
paper-button.warning[raised], paper-button.btn-warning[raised], paper-button[warning][raised] { background-color: #fadd60; color: #4b421d; }
paper-button.error, paper-button.btn-error, paper-button[error] { color: #ff6e40; }
paper-button.error[raised], paper-button.btn-error[raised], paper-button[error][raised] { background-color: #ff6e40; color: #4d2113; }
paper-button.link, paper-button.btn-link, paper-button[link] { text-decoration: underline; }
paper-button[raised] { color: #444444; }
paper-button[disabled] { color: #313238 !important; background: #afb1b9 !important; }

paper-icon-button.primary, paper-icon-button.btn-primary, paper-icon-button[primary] { color: #373b50; }
paper-icon-button.primary:hover, paper-icon-button.btn-primary:hover, paper-icon-button[primary]:hover { background-color: #ebebee; background-color: rgba(55, 59, 80, 0.2); border-radius: 50%; }
paper-icon-button.secondary, paper-icon-button.btn-secondary, paper-icon-button[secondary] { color: #90a4ae; }
paper-icon-button.secondary:hover, paper-icon-button.btn-secondary:hover, paper-icon-button[secondary]:hover { background-color: #f4f6f7; background-color: rgba(144, 164, 174, 0.2); border-radius: 50%; }
paper-icon-button.success, paper-icon-button.btn-success, paper-icon-button[success] { color: #9dc56e; }
paper-icon-button.success:hover, paper-icon-button.btn-success:hover, paper-icon-button[success]:hover { background-color: #f5f9f1; background-color: rgba(157, 197, 110, 0.2); border-radius: 50%; }
paper-icon-button.info, paper-icon-button.btn-info, paper-icon-button[info] { color: #ffb74d; }
paper-icon-button.info:hover, paper-icon-button.btn-info:hover, paper-icon-button[info]:hover { background-color: #fff8ed; background-color: rgba(255, 183, 77, 0.2); border-radius: 50%; }
paper-icon-button.warning, paper-icon-button.btn-warning, paper-icon-button[warning] { color: #fadd60; }
paper-icon-button.warning:hover, paper-icon-button.btn-warning:hover, paper-icon-button[warning]:hover { background-color: #fffcef; background-color: rgba(250, 221, 96, 0.2); border-radius: 50%; }
paper-icon-button.error, paper-icon-button.btn-error, paper-icon-button[error] { color: #ff6e40; }
paper-icon-button.error:hover, paper-icon-button.btn-error:hover, paper-icon-button[error]:hover { background-color: #fff1ec; background-color: rgba(255, 110, 64, 0.2); border-radius: 50%; }

paper-checkbox #checkmark.paper-checkbox, paper-checkbox /deep/, paper-checkbox::shadow #checkmark.paper-checkbox { border-color: #fff !important; }

paper-dialog { color: #444444; background-color: #ffffff; font-family: 'Source Sans Pro', sans-serif; font-weight: 400; }
paper-dialog h1, paper-dialog h2, paper-dialog h3, paper-dialog h4, paper-dialog h5, paper-dialog h6 { overflow: visible; padding: 0 1em; text-align: center; }

paper-fab { --text-primary-color: white; }

paper-fab { background-color: #373b50; color: #fff; --paper-fab-keyboard-focus-background: #6c749a; }
paper-fab.primary, paper-fab.btn-primary, paper-fab[primary] { background-color: #373b50; color: #fff; --paper-fab-keyboard-focus-background: #6c749a; }
paper-fab.secondary, paper-fab.btn-secondary, paper-fab[secondary] { background-color: #90a4ae; color: #2b3134; --paper-fab-keyboard-focus-background: #50646e; }
paper-fab.success, paper-fab.btn-success, paper-fab[success] { background-color: #9dc56e; color: #2f3b21; --paper-fab-keyboard-focus-background: #5d8033; }
paper-fab.info, paper-fab.btn-info, paper-fab[info] { background-color: #ffb74d; color: #4d3717; --paper-fab-keyboard-focus-background: #cd7a00; }
paper-fab.warning, paper-fab.btn-warning, paper-fab[warning] { background-color: #fadd60; color: #4b421d; --paper-fab-keyboard-focus-background: #d4ad07; }
paper-fab.error, paper-fab.btn-error, paper-fab[error] { background-color: #ff6e40; color: #4d2113; --paper-fab-keyboard-focus-background: #c02e00; }
paper-fab[disabled] { color: #313238 !important; background: #afb1b9 !important; }

section.hero paper-menu, section[hero] paper-menu { --paper-menu-background-color: #f2f7fa; }

paper-tabs { background-color: #373b50; color: #ffffff; }
